BlueClaw Trace Dashboard

## Traces

All Success Error Last 7d

| Run ID | Goal | Model | Steps | Tokens | Cost | Duration | Status
--- | --- | --- | --- | --- | --- | --- | --- | ---

No traces found. Run an agent session to generate traces.

Select a trace from the list to view details.

## Compare Traces

Select 2 traces from the list using the checkboxes, then switch to Compare.

## Stats

Last 7 days Last 30 days All time

No stats available yet. Run some agent sessions first.